@@ -9,12 +9,15 @@ import (
 	"errors"
 	"fmt"
 	"log"
+	"os"
 	"strconv"
 	"strings"
 	"time"
 
 	"github.com/la5nta/pat/cfg"
+	"github.com/la5nta/pat/internal/buildinfo"
 	"github.com/la5nta/pat/internal/debug"
+	"github.com/la5nta/pat/internal/prehook"
 
 	"github.com/harenber/ptc-go/v2/pactor"
 	"github.com/la5nta/wl2k-go/transport"
@@ -184,6 +187,13 @@ func Connect(connectStr string) (success bool) {
 	dialing = url
 	websocketHub.UpdateStatus()
 
+	if exec := url.Params.Get("prehook"); exec != "" {
+		if err := prehook.Verify(exec); err != nil {
+			log.Printf("prehook invalid: %s", err)
+			return
+		}
+	}
+
 	log.Printf("Connecting to %s (%s)...", url.Target, url.Scheme)
 	conn, err := transport.DialURLContext(ctx, url)
 
@@ -202,6 +212,26 @@ func Connect(connectStr string) (success bool) {
 		return
 	}
 
+	if exec := url.Params.Get("prehook"); exec != "" {
+		log.Println("Running prehook...")
+		script := prehook.Script{
+			File: exec,
+			Args: url.Params["prehook-arg"],
+			Env: append([]string{
+				buildinfo.AppName + "_DIAL_URL=" + connectStr,
+				buildinfo.AppName + "_REMOTE_ADDR=" + conn.RemoteAddr().String(),
+				buildinfo.AppName + "_LOCAL_ADDR=" + conn.LocalAddr().String(),
+			}, append(os.Environ(), envAll()...)...),
+		}
+		conn = prehook.Wrap(conn)
+		if err := script.Execute(ctx, conn); err != nil {
+			conn.Close()
+			log.Printf("Prehook script failed: %s", err)
+			return
+		}
+		log.Println("Prehook succeeded")
+	}
+
 	err = exchange(conn, url.Target, false)
 	if err != nil {
 		log.Printf("Exchange failed: %s", err)
