@@ -32,6 +32,8 @@ import (
 	"github.com/la5nta/wl2k-go/transport/ardop"
 
 	"github.com/la5nta/pat/internal/buildinfo"
+	"github.com/la5nta/pat/internal/debug"
+	"github.com/la5nta/pat/internal/directories"
 	"github.com/la5nta/pat/internal/gpsd"
 
 	"github.com/gorilla/mux"
@@ -216,11 +218,6 @@ func postPositionHandler(w http.ResponseWriter, r *http.Request) {
 	}
 }
 
-func isInPath(base string, path string) error {
-	_, err := filepath.Rel(base, path)
-	return err
-}
-
 func postMessageHandler(w http.ResponseWriter, r *http.Request) {
 	box := mux.Vars(r)["box"]
 	if box == "out" {
@@ -239,9 +236,9 @@ func postMessageHandler(w http.ResponseWriter, r *http.Request) {
 
 	// Check that we don't escape our mailbox path
 	srcPath = filepath.Clean(srcPath)
-	if err := isInPath(mbox.MBoxPath, srcPath); err != nil {
-		log.Println("Malicious source path in move:", err)
-		http.Error(w, err.Error(), http.StatusBadRequest)
+	if !directories.IsInPath(mbox.MBoxPath, srcPath) {
+		log.Println("Malicious source path in move:", srcPath)
+		http.Error(w, "malicious source path", http.StatusBadRequest)
 		return
 	}
 
@@ -269,7 +266,7 @@ func postOutboundMessageHandler(w http.ResponseWriter, r *http.Request) {
 	if r.MultipartForm != nil {
 		files := r.MultipartForm.File["files"]
 		for _, f := range files {
-			err := attachFile(f, msg)
+			err := addAttachmentFromMultipartFile(msg, f)
 			switch err := err.(type) {
 			case nil:
 				// No problem
@@ -281,12 +278,20 @@ func postOutboundMessageHandler(w http.ResponseWriter, r *http.Request) {
 		}
 	}
 
-	cookie, err := r.Cookie("forminstance")
-	if err == nil {
-		formData := formsMgr.GetPostedFormData(cookie.Value)
-		if xml := formData.MsgXML; xml != "" {
-			name := formsMgr.GetXMLAttachmentNameForForm(formData.TargetForm, formData.IsReply)
-			msg.AddFile(fbb.NewFile(name, []byte(formData.MsgXML)))
+	if cookie, err := r.Cookie("forminstance"); err == nil {
+		// We must add the attachment files here because it is impossible
+		// for the frontend to dynamically add form files due to legacy
+		// security vulnerabilities in older HTML specs.
+		// The rest of the form data (to, subject, body etc) is added by
+		// the frontend.
+		formData, ok := formsMgr.GetPostedFormData(cookie.Value)
+		if !ok {
+			debug.Printf("form instance key (%q) not valid", cookie.Value)
+			http.Error(w, "form instance key not valid", http.StatusBadRequest)
+			return
+		}
+		for _, f := range formData.Attachments {
+			msg.AddFile(f)
 		}
 	}
 
@@ -340,7 +345,7 @@ func postOutboundMessageHandler(w http.ResponseWriter, r *http.Request) {
 	_, _ = fmt.Fprintf(w, "Message posted (%.2f kB)", float64(buf.Len()/1024))
 }
 
-func attachFile(f *multipart.FileHeader, msg *fbb.Message) error {
+func addAttachmentFromMultipartFile(msg *fbb.Message, f *multipart.FileHeader) error {
 	// For some unknown reason, we receive this empty unnamed file when no
 	// attachment is provided. Prior to Go 1.10, this was filtered by
 	// multipart.Reader.
@@ -356,28 +361,10 @@ func attachFile(f *multipart.FileHeader, msg *fbb.Message) error {
 	if err != nil {
 		return HTTPError{err, http.StatusInternalServerError}
 	}
-
-	p, err := io.ReadAll(file)
-	_ = file.Close()
-	if err != nil {
+	defer file.Close()
+	if err := addAttachment(msg, f.Filename, f.Header.Get("Content-Type"), file); err != nil {
 		return HTTPError{err, http.StatusInternalServerError}
 	}
-
-	if isConvertableImageMediaType(f.Filename, f.Header.Get("Content-Type")) {
-		log.Printf("Auto converting '%s' [%s]...", f.Filename, f.Header.Get("Content-Type"))
-
-		if converted, err := convertImage(p); err != nil {
-			log.Printf("Error converting image: %s", err)
-		} else {
-			log.Printf("Done converting '%s'.", f.Filename)
-
-			ext := path.Ext(f.Filename)
-			f.Filename = f.Filename[:len(f.Filename)-len(ext)] + ".jpg"
-			p = converted
-		}
-	}
-
-	msg.AddFile(fbb.NewFile(f.Filename, p))
 	return nil
 }
 
@@ -678,9 +665,9 @@ func messageDeleteHandler(w http.ResponseWriter, r *http.Request) {
 	box, mid := mux.Vars(r)["box"], mux.Vars(r)["mid"]
 
 	file := filepath.Clean(filepath.Join(mbox.MBoxPath, box, mid+mailbox.Ext))
-	if err := isInPath(mbox.MBoxPath, file); err != nil {
-		log.Println("Malicious source path in move:", err)
-		http.Error(w, err.Error(), http.StatusBadRequest)
+	if !directories.IsInPath(mbox.MBoxPath, file) {
+		log.Println("Malicious source path in move:", file)
+		http.Error(w, "malicious source path", http.StatusBadRequest)
 		return
 	}
 
