@@ -153,6 +153,13 @@ var commands = []Command{
 			}
 		},
 	},
+	{
+		Str:        "account",
+		Desc:       "Get and set Winlink.org account settings.",
+		Usage:      accountUsage,
+		Example:    accountExample,
+		HandleFunc: accountHandle,
+	},
 	{
 		Str:        "configure",
 		Desc:       "Open configuration file for editing.",
@@ -350,7 +357,7 @@ func main() {
 		FormsPath:  fOptions.FormsPath,
 		MyCall:     fOptions.MyCall,
 		Locator:    config.Locator,
-		AppVersion: buildinfo.VersionStringShort(),
+		AppVersion: buildinfo.AppName + " " + buildinfo.VersionStringShort(),
 		UserAgent:  buildinfo.UserAgent(),
 		LineReader: readLine,
 		GPSd:       config.GPSd,
@@ -370,10 +377,10 @@ func main() {
 			if config.VersionReportingDisabled {
 				return
 			}
-
-			for { // Check every 6 hours, but it won't post more frequent than 24h.
-				postVersionUpdate() // Ignore errors
-				time.Sleep(6 * time.Hour)
+			for {
+				postVersionUpdate()                  // 24 hour hold on success
+				checkPasswordRecoveryEmailIsSet(ctx) // 14 day hold on success
+				time.Sleep(6 * time.Hour)            // Retry every 6 hours
 			}
 		}()
 	}
